Welcome to eisenmp’s documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   details
   modconf
   work_conf
   constants
   eisenmp
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
